==> nextcloud-app-calendar-1.5.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/sq.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Kalendar",
    "%s has published the calendar \"%s\"" : "%s ka publikuar kalendarin \"%s\"",
    "Too many redirects. Aborting ..." : "Shumë ridrejtime. Duke e ndërprerë ...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Serveri i largët nuk na dha akses në kalendar (gabim HTTP {%s})",
    "Error connecting to remote server" : "Gabim gjatë lidhjes me serverin e largët",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Gabim gjatë kërkimit të burimit në serverin e largët. Kjo mund të jetë e lidhur me një mospërputhje të çertifikatave.",
    "Error requesting resource on remote server" : "Gabim gjatë kërkimit të burimit në serverin e largët.",
    "Individual" : "Individual",
    "Group" : "Grup",
    "Resource" : "Burim",
    "Room" : "Dhomë",
    "Unknown" : "E panjohur",
    "Required" : "E domosdoshme",
    "Optional" : "Jo i detyrueshëm",
    "Does not attend" : "Nuk merr pjesë",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Gjendeni një zonë kohore të panjohur ({tz}), po përdoret parazgjedhja UTC",
    "Please create a calendar first." : "Ju lutemi, së pari krijoni një kalendar.",
    "New event" : "Veprimtari e re",
    "CalDAV address for clients" : "Adresa CalDAV për klientët",
    "Error saving WebCal-calendar" : "Gabim në ruajtje kalendari WebCal-calendar",
    "WebDAV address for subscriptions" : "Adresa WebDAV për abonimet",
    "EMail has been sent." : "EMail-i u dërgua",
    "There was an issue while sending your EMail." : "Pati një problem gjatë dërgimit të emailit tuaj",
    "group" : "grup",
    "Details" : "Detajet",
    "Attendees" : "Pjesëmarrës",
    "Reminders" : "Kujtues",
    "Repeating" : "Përsëritëse",
    "When shared show full event" : "Kur ndahet shfaqje e veprimtarisë së plotë",
    "When shared show only busy" : "Kur ndahet shfaqje vetëm i zënë",
    "When shared hide this event" : "Kur ndahet fshihe këtë veprimtari",
    "Confirmed" : "E konfirmuar",
    "Tentative" : "Në tentativë",
    "Cancelled" : "Anuluar",
    "Please add a title!" : "Ju lutemi, shtoni një titull!",
    "Please select a calendar!" : "Ju lutemi, përzgjidhni një kalendar",
    "Global" : "Globale",
    "None" : "Asnjë",
    "Every day" : "Çdo ditë",
    "Every week" : "Çdo javë",
    "Every month" : "Çdo muaj",
    "Every year" : "Çdo vit",
    "never" : "kurrë",
    "after" : "pas",
    "How about getting started by importing some calendars?" : "Po sikur të filloni duke ngarkuar disa kalendare?",
    "At time of event" : "Në kohën e veprimtarisë",
    "5 minutes before" : "5 minuta para",
    "10 minutes before" : "10 minuta para",
    "15 minutes before" : "15 minuta para",
    "30 minutes before" : "30 minuta para",
    "1 hour before" : "1 orë para",
    "2 hours before" : "2 orë para",
    "Custom" : "E përshtatur",
    "Audio" : "Audio",
    "E Mail" : "Email",
    "Pop up" : "Shfaqe si flluskë",
    "sec" : "sek",
    "min" : "min",
    "hours" : "orë",
    "days" : "ditë",
    "week" : "javë",
    "before" : "përpara",
    "start" : "fillim",
    "end" : "mbarim",
    "Editing reminders of unknown type not supported." : "Nuk mbulohet përpunimi i kujtuesve të një lloji të panjohur.",
    "Week {number} of {year}" : "Java e {number} e {year}",
    "Successfully imported" : "U importua me sukses",
    "Partially imported, 1 failure" : "Importuar pjesërisht, 1 dështim",
    "Partially imported, {n} failures" : "Importuar pjesërisht, {n} dështime",
    "Audio alarm" : "Alarm audio",
    "Pop-up" : "Flluskë",
    "E-Mail" : "Email",
    "{type} {time} before the event starts" : "{type} {time} para se veprimtaria të fillojë",
    "{type} {time} before the event ends" : "{type} {time} para se veprimtaria të përfundojë",
    "{type} {time} after the event starts" : "{type} {time} pas fillimit të veprimtarisë",
    "{type} {time} after the event ends" : "{type} {time} pas mbarimit të veprimtarisë",
    "{type} at the event's start" : "{type} në fillim të veprimtarisë",
    "{type} at the event's end" : "{type} në fund të veprimtarisë",
    "{type} at {time}" : "{type} në {time}",
    "{calendar} shared by {owner}" : "{calendar} ndarë nga {owner}",
    "Please enter a valid WebCal-URL" : "Ju lutemi, jepni një url të vlefshme WebCal-URL",
    "Severe error in webcal proxy. Please contact administrator for more information." : "Gabim i rëndë në webcal proxy. Ju lutemi, kontaktoni administratorin për më shumë informacion.",
    "Title of the Event" : "Titulli i Veprimtarisë",
    "Starts" : "Fillim",
    "Ends" : "Mbarim",
    "All day Event" : "Veprimtari Gjithëditore",
    "Delete" : "Fshije",
    "Cancel" : "Anuloje",
    "More ..." : "Më tepër …",
    "Create" : "Krijoje",
    "Update" : "Përditësoje",
    "Close" : "Mbylle",
    "Location" : "Vendndodhje",
    "Description" : "Përshkrim",
    "Event status" : "Gjendje veprimtarie",
    "Visibility when sharing" : "Dukshmëri gjatë ndarjes me të tjerë",
    "Export" : "Eksportoji",
    "%s has published the calendar %s" : "%s ka publikuar kalendarin %s",
    "Hello," : "Përshëndetje,",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Donim t'ju informanim se %s ka publikuar kalendarin {boldstart}%s{boldend}.",
    "Click here to access it" : "Klikoni këtu për ta aksesuar atë",
    "Cheers!" : "Gëzuar!",
    "We wanted to inform you that %s has published the calendar %s." : "Donim t'ju informanim se %s ka publikuar kalendarin %s.",
    "Click on the link below to access it" : "Klikoni lidhjen e mëposhtme për ta aksesuar atë",
    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Për shkak të një të mete në degën kryesore, kalendari, hëpërhë, s’është në gjendje të ofrojë mbulim të veçorinë \"asset pipeline\".",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Ju lutemi, lidhuni me përgjegjësin tuaj dhe kërkojini të çaktivizojë mundësinë \"asset-pipeline.enabled\" te formësimet.",
    "Day" : "Ditë",
    "Week" : "Javë",
    "Month" : "Muaj",
    "Today" : "Sot",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Disa nga veprimtaritë në këtë kalendar janë të dëmtuara. Ju lutemi, për më tepër të dhëna, kontrolloni te konsola JS.",
    "Share Calendar" : "Ndani Kalendarin",
    "Shared" : "E ndarë",
    "More" : "Më tepër",
    "Edit" : "Përpunoni",
    "Link" : "Lidhje",
    "Download" : "Shkarkoje",
    "Share with users or groups" : "Ndajeni me përdorues ose grupe",
    "can edit" : "mund të përpunojnë",
    "Share link" : "Ndani lidhjen",
    "Public access" : "Akses publik",
    "Email link to person" : "Dërgoja linkun personit me email",
    "Send" : "Dërgo",
    "New Calendar" : "Kalendar i ri",
    "Name" : "Emër",
    "New Subscription" : "Pajtim i Ri",
    "Go back" : "Shko prapa",
    "Go forward" : "Shko para",
    "Edit event" : "Përpunoni veprimtarinë",
    "Delete Event" : "Fshije Veprimtarinë",
    "Save Event" : "Ruaje Veprimtarinë",
    "Time" : "Kohë",
    "Type" : "Lloj",
    "Relative" : "Relative",
    "Absolute" : "Absolute",
    "Repeat" : "Përsërite",
    "times every" : "herë çdo",
    "Add" : "Shtoje",
    "E-Mail address of attendee" : "Adresa email e pjesëmarrësit",
    "Please add your email address in the personal settings in order to add attendees." : "Që të shtoni pjesëmarrës, ju lutemi, shtoni adresën tuaj email te rregullimet personale.",
    "from" : "nga",
    "to" : "për",
    "This event's repeating rule is not supported yet." : "Ky rregull përsëritjesh veprimtarie nuk mbulohet ende.",
    "Support for advanced rules will be added with subsequent updates." : "Mbulimi i rregullave të thelluara do të shtohet në përditësimet e ardhshme.",
    "Reset repeating rule" : "Ricaktoni rregull përsëritje",
    "Repeat every ..." : "Përsërite çdo …",
    "end repeat ..." : "përfundoje përsëritjen më …",
    "times" : "herë",
    "Import Calendars" : "Importoni Kalendarë",
    "Import canceled" : "Importimi u anulua",
    "Analyzing calendar" : "Analizim kalendari",
    "The file contains objects incompatible with the selected calendar" : "Kartela përmban objekte të papërputhshme me kalendarin e përzgjedhur",
    "New calendar" : "Kalendar i ri",
    "File is empty" : "Skedari është bosh",
    "Import scheduled" : "Importimi u planifikua",
    "Publish URL" : "Publiko URL",
    "Settings & import" : "Konfigurimet dhe importi",
    "Skip simple event editor" : "Anashkaloje përpunuesin e thjeshtë të veprimtarive",
    "Show week numbers" : "Shfaq numra javësh",
    "Import calendar" : "Importo kalendar",
    "No Calendars selected for import" : "S’ka Kalendarë të përzgjedhur për import",
    "Primary CalDAV address" : "Adresë CalDAV parësore",
    "iOS/OS X CalDAV address" : "Adresë iOS/OS X CalDAV"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-calendar-1.5.6-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/sq.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Kalendar",
    "%s has published the calendar »%s«" : "%s ka publikuar kalendarin %s",
    "Hello," : "Përshëndetje,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Donim t'ju informonim se %s ka publikuar kalendarin »%s«",
    "Open »%s«" : "Hap »%s«",
    "Cheers!" : "Gëzuar!",
    "Recipient" : "Marrës",
    "Too many redirects. Aborting ..." : "Shumë ridrejtime. Duke e ndërprerë ...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Serveri i largët nuk na dha akses në kalendar (gabim HTTP {%s})",
    "Error connecting to remote server" : "Gabim gjatë lidhjes me serverin e largët",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Gabim gjatë kërkimit të burimit në serverin e largët. Kjo mund të jetë e lidhur me një mospërputhje të çertifikatave.",
    "Error requesting resource on remote server" : "Gabim gjatë kërkimit të burimit në serverin e largët.",
    "Individual" : "Individual",
    "Group" : "Grup",
    "Resource" : "Burim",
    "Room" : "Dhomë",
    "Unknown" : "E panjohur",
    "Required" : "E domosdoshme",
    "Optional" : "Jo i detyrueshëm",
    "Does not attend" : "Nuk merr pjesë",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Gjendeni një zonë kohore të panjohur ({tz}), po përdoret parazgjedhja UTC",
    "Please create a calendar first." : "Ju lutemi, së pari krijoni një kalendar.",
    "New event" : "Veprimtari e re",
    "CalDAV address for clients" : "Adresa CalDAV për klientët",
    "Error saving WebCal-calendar" : "Gabim në ruajtje kalendari WebCal-calendar",
    "WebDAV address for subscriptions" : "Adresa WebDAV për abonimet",
    "Email has been sent." : "Emaili u dërgua",
    "There was an issue while sending your email." : "Pati një problem me dërgimin e emailit tuaj.",
    "group" : "grup",
    "Details" : "Detajet",
    "Attendees" : "Pjesëmarrës",
    "Reminders" : "Kujtues",
    "Repeating" : "Përsëritëse",
    "When shared show full event" : "Kur ndahet shfaqje e veprimtarisë së plotë",
    "When shared show only busy" : "Kur ndahet shfaqje vetëm i zënë",
    "When shared hide this event" : "Kur ndahet fshihe këtë veprimtari",
    "Confirmed" : "E konfirmuar",
    "Tentative" : "Në tentativë",
    "Cancelled" : "Anuluar",
    "Please add a title." : "Ju lutemi shtoni një titull.",
    "Please select a calendar." : "Ju lutemi selektoni një kalendar.",
    "The event can not end before it starts." : "Ngjarja nuk mund të përfundojë para se të fillojë.",
    "Global" : "Globale",
    "None" : "Asnjë",
    "Every day" : "Çdo ditë",
    "Every week" : "Çdo javë",
    "Every month" : "Çdo muaj",
    "Every year" : "Çdo vit",
    "never" : "kurrë",
    "after" : "pas",
    "How about getting started by importing some calendars?" : "Po sikur të filloni duke ngarkuar disa kalendare?",
    "At time of event" : "Në kohën e veprimtarisë",
    "5 minutes before" : "5 minuta para",
    "10 minutes before" : "10 minuta para",
    "15 minutes before" : "15 minuta para",
    "30 minutes before" : "30 minuta para",
    "1 hour before" : "1 orë para",
    "2 hours before" : "2 orë para",
    "Custom" : "E përshtatur",
    "Audio" : "Audio",
    "Email" : "Emaili",
    "Pop-up" : "Flluskë",
    "sec" : "sek",
    "min" : "min",
    "hours" : "orë",
    "days" : "ditë",
    "week" : "javë",
    "before" : "përpara",
    "start" : "fillim",
    "end" : "mbarim",
    "Editing reminders of unknown type not supported." : "Nuk mbulohet përpunimi i kujtuesve të një lloji të panjohur.",
    "Week {number} of {year}" : "Java e {number} e {year}",
    "Successfully imported" : "U importua me sukses",
    "Partially imported, 1 failure" : "Importuar pjesërisht, 1 dështim",
    "Partially imported, {n} failures" : "Importuar pjesërisht, {n} dështime",
    "Audio alarm" : "Alarm audio",
    "{type} {time} before the event starts" : "{type} {time} para se veprimtaria të fillojë",
    "{type} {time} before the event ends" : "{type} {time} para se veprimtaria të përfundojë",
    "{type} {time} after the event starts" : "{type} {time} pas fillimit të veprimtarisë",
    "{type} {time} after the event ends" : "{type} {time} pas mbarimit të veprimtarisë",
    "{type} at the event's start" : "{type} në fillim të veprimtarisë",
    "{type} at the event's end" : "{type} në fund të veprimtarisë",
    "{type} at {time}" : "{type} në {time}",
    "{calendar} shared by {owner}" : "{calendar} ndarë nga {owner}",
    "Please enter a valid WebCal-URL" : "Ju lutemi, jepni një url të vlefshme WebCal-URL",
    "Severe error in webcal proxy. Please contact administrator for more information." : "Gabim i rëndë në webcal proxy. Ju lutemi, kontaktoni administratorin për më shumë informacion.",
    "Title of the Event" : "Titulli i Veprimtarisë",
    "Starts" : "Fillim",
    "Ends" : "Mbarim",
    "All day Event" : "Veprimtari Gjithëditore",
    "Delete" : "Fshije",
    "Cancel" : "Anuloje",
    "More ..." : "Më tepër …",
    "Create" : "Krijoje",
    "Update" : "Përditësoje",
    "Close" : "Mbylle",
    "Location" : "Vendndodhje",
    "Description" : "Përshkrim",
    "Event status" : "Gjendje veprimtarie",
    "Visibility when sharing" : "Dukshmëri gjatë ndarjes me të tjerë",
    "Export" : "Eksportoji",
    "%s has published the calendar %s" : "%s ka publikuar kalendarin %s",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Donim t'ju informanim se %s ka publikuar kalendarin {boldstart}%s{boldend}.",
    "Click here to access it" : "Klikoni këtu për ta aksesuar atë",
    "We wanted to inform you that %s has published the calendar %s." : "Donim t'ju informanim se %s ka publikuar kalendarin %s.",
    "Click on the link below to access it" : "Klikoni lidhjen e mëposhtme për ta aksesuar atë",
    "Day" : "Ditë",
    "Week" : "Javë",
    "Month" : "Muaj",
    "Today" : "Sot",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Disa nga veprimtaritë në këtë kalendar janë të dëmtuara. Ju lutemi, për më tepër të dhëna, kontrolloni te konsola JS.",
    "Share Calendar" : "Ndani Kalendarin",
    "Shared" : "E ndarë",
    "More" : "Më tepër",
    "Edit" : "Përpunoni",
    "Link" : "Lidhje",
    "iCal link" : "Linku i iCal",
    "Download" : "Shkarkoje",
    "Share with users or groups" : "Ndajeni me përdorues ose grupe",
    "can edit" : "mund të përpunojnë",
    "Share link" : "Ndani lidhjen",
    "Public access" : "Akses publik",
    "Email link to person" : "Dërgoja linkun personit me email",
    "Send" : "Dërgo",
    "New Calendar" : "Kalendar i ri",
    "Name" : "Emër",
    "New Subscription" : "Pajtim i Ri",
    "Go back" : "Shko prapa",
    "Go forward" : "Shko para",
    "Calendar does not exist" : "Kalendari nuk ekziston",
    "Maybe you got a wrong link or the calendar was unshared?" : "Ndoshta ju keni linkun e gabuar ose kalendari nuk ndahet më me ju?",
    "Edit event" : "Përpunoni veprimtarinë",
    "Delete Event" : "Fshije Veprimtarinë",
    "Save Event" : "Ruaje Veprimtarinë",
    "Time" : "Kohë",
    "Type" : "Lloj",
    "Relative" : "Relative",
    "Absolute" : "Absolute",
    "Repeat" : "Përsërite",
    "times every" : "herë çdo",
    "Add" : "Shtoje",
    "Email address of attendee" : "Adresa e emailit e pjesmarrësit",
    "Please add your email address in the personal settings in order to add attendees." : "Që të shtoni pjesëmarrës, ju lutemi, shtoni adresën tuaj email te rregullimet personale.",
    "from" : "nga",
    "to" : "për",
    "This event's repeating rule is not supported yet." : "Ky rregull përsëritjesh veprimtarie nuk mbulohet ende.",
    "Support for advanced rules will be added with subsequent updates." : "Mbulimi i rregullave të thelluara do të shtohet në përditësimet e ardhshme.",
    "Reset repeating rule" : "Ricaktoni rregull përsëritje",
    "Repeat every ..." : "Përsërite çdo …",
    "end repeat ..." : "përfundoje përsëritjen më …",
    "times" : "herë",
    "Import Calendars" : "Importoni Kalendarë",
    "Import canceled" : "Importimi u anulua",
    "Analyzing calendar" : "Analizim kalendari",
    "The file contains objects incompatible with the selected calendar" : "Kartela përmban objekte të papërputhshme me kalendarin e përzgjedhur",
    "New calendar" : "Kalendar i ri",
    "File is empty" : "Skedari është bosh",
    "Import scheduled" : "Importimi u planifikua",
    "%s shared the calendar <strong>%s</strong> with you" : "%sndau kalendarin <strong>%s</strong>me ju",
    "Embed" : "Ngulit",
    "Iframe to integrate" : "Iframe që do të integrohet",
    "Publish URL" : "Publiko URL",
    "Settings & import" : "Konfigurimet dhe importi",
    "Skip simple event editor" : "Anashkaloje përpunuesin e thjeshtë të veprimtarive",
    "Show week numbers" : "Shfaq numra javësh",
    "Import calendar" : "Importo kalendar",
    "No Calendars selected for import" : "S’ka Kalendarë të përzgjedhur për import",
    "Primary CalDAV address" : "Adresë CalDAV parësore",
    "iOS/OS X CalDAV address" : "Adresë iOS/OS X CalDAV",
    "Subscribe" : "Abonohu"
},
"nplurals=2; plural=(n != 1);");
